summaryrefslogtreecommitdiffstats
path: root/klaptopdaemon/daemondock.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-04 14:19:04 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-04 14:19:04 -0600
commit34ec7cf1e70300eb43f3822ce3261893f9f8ace6 (patch)
treec7fe414e406e16a97e53d9eed0979d9ea85d2915 /klaptopdaemon/daemondock.cpp
parente6b6046f50ea600fc78e00071e2a79e3c8c08ccd (diff)
downloadtdeutils-34ec7cf1e70300eb43f3822ce3261893f9f8ace6.tar.gz
tdeutils-34ec7cf1e70300eb43f3822ce3261893f9f8ace6.zip
Rename KIcon to enhance compatibility with KDE4
Diffstat (limited to 'klaptopdaemon/daemondock.cpp')
-rw-r--r--klaptopdaemon/daemondock.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/klaptopdaemon/daemondock.cpp b/klaptopdaemon/daemondock.cpp
index d18702e..f734de0 100644
--- a/klaptopdaemon/daemondock.cpp
+++ b/klaptopdaemon/daemondock.cpp
@@ -715,7 +715,7 @@ quit:
// "This function is slow because it involves transformation to a TQImage,
// non-trivial computations and a transformation back to a TQBitmap."). Then
// I have to convert the resulting TQPixmap to a TQImage in order to overlay
// the light KMail icon with the number (because KIconEffect::overlay only
// works with TQImage). Finally the resulting TQImage has to be converted
// back to a TQPixmap.
// That's a lot of work for overlaying the KMail icon with the number of
@@ -732,7 +732,7 @@ quit:
// Overlay the light KMail icon with the number image
TQImage iconWithPercentageImage = image.copy();
- KIconEffect::overlay( iconWithPercentageImage, percentageImage );
+ TDEIconEffect::overlay( iconWithPercentageImage, percentageImage );
TQPixmap iconWithPercentage;
iconWithPercentage.convertFromImage( iconWithPercentageImage );
@@ -715,7 +715,7 @@ quit:
// non-trivial computations and a transformation back to a TQBitmap."). Then
// I have to convert the resulting TQPixmap to a TQImage in order to overlay
- // the light KMail icon with the number (because KIconEffect::overlay only
+ // the light KMail icon with the number (because TDEIconEffect::overlay only
// works with TQImage). Finally the resulting TQImage has to be converted
// back to a TQPixmap.